Trait CryptoBlockRng
trait CryptoBlockRng: BlockRngCore
A marker trait used to indicate that an RngCore implementation is
supposed to be cryptographically secure.
See CryptoRng docs for more information.
CryptoBlockRngtrait CryptoBlockRng: BlockRngCore
A marker trait used to indicate that an RngCore implementation is
supposed to be cryptographically secure.
See CryptoRng docs for more information.