Struct OsError

struct OsError(_)

Error type of OsRng

Implementations

impl OsError

fn raw_os_error(self: Self) -> Option<i32>

Extract the raw OS error code (if this error came from the OS)

This method is identical to std::io::Error::raw_os_error(), except that it works in no_std contexts. If this method returns None, the error value can still be formatted via the Display implementation.

impl Clone for OsError

fn clone(self: &Self) -> OsError

impl Copy for OsError

impl Debug for OsError

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Display for OsError

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Eq for OsError

impl Error for OsError

fn source(self: &Self) -> Option<&dyn Error + 'static>

impl Freeze for OsError

impl PartialEq for OsError

fn eq(self: &Self, other: &OsError) -> bool

impl RefUnwindSafe for OsError

impl Send for OsError

impl StructuralPartialEq for OsError

impl Sync for OsError

impl Unpin for OsError

impl UnsafeUnpin for OsError

impl UnwindSafe for OsError

impl<T> Any for OsError

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for OsError

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for OsError

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for OsError

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for OsError

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for OsError

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T> ToString for OsError

fn to_string(self: &Self) -> String

impl<T, U> Into for OsError

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for OsError

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for OsError

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>