Trait TryCryptoRng

trait TryCryptoRng: TryRngCore

A marker trait used to indicate that a TryRngCore implementation is supposed to be cryptographically secure.

See CryptoRng docs for more information about cryptographically secure generators.

Implementors