Trait TryCryptoRng
trait TryCryptoRng: TryRngCore
A marker trait used to indicate that a TryRngCore implementation is
supposed to be cryptographically secure.
See CryptoRng docs for more information about cryptographically secure generators.
Implementors
impl<R: CryptoRng> TryCryptoRng for Rimpl<R> TryCryptoRng for BlockRng<R>impl TryCryptoRng for OsRngimpl<R> TryCryptoRng for BlockRng64<R>impl<R> TryCryptoRng for UnwrapErr<R>